@@ -1,5 +1,5 @@
-from __future__ import unicode_literals
 from __future__ import absolute_import
+from __future__ import unicode_literals
 
 """
 pypuppetdb PuppetDB API library
@@ -47,7 +47,7 @@ We can also query for facts:
    osfamily/host1
    osfamily/host2
 
-That querries PuppetDB for the 'osfamily' fact and will yield Fact objects,
+That queries PuppetDB for the 'osfamily' fact and will yield Fact objects,
 one per node this fact is found on.
 
    >>> resources = db.resources('file')
@@ -58,16 +58,9 @@ number of nodes as the response will be huge.
 """
 import logging
 
-from pypuppetdb.api import BaseAPI
+from pypuppetdb.api import API
 
-try:  # Python 2.7+
-    from logging import NullHandler
-except ImportError:  # pragma: notest
-    class NullHandler(logging.Handler):
-        def emit(self, record):
-            pass
-
-logging.getLogger(__name__).addHandler(NullHandler())
+logging.getLogger(__name__).addHandler(logging.NullHandler())
 
 
 def connect(host='localhost', port=8080, ssl_verify=False, ssl_key=None,
@@ -116,7 +109,7 @@ def connect(host='localhost', port=8080, ssl_verify=False, ssl_key=None,
     :param token: (optional) The x-auth token to use for X-Authentication
     :type token: :obj:`None` or :obj:`string`
     """
-    return BaseAPI(host=host, port=port,
-                   timeout=timeout, ssl_verify=ssl_verify, ssl_key=ssl_key,
-                   ssl_cert=ssl_cert, protocol=protocol, url_path=url_path,
-                   username=username, password=password, token=token)
+    return API(host=host, port=port,
+               timeout=timeout, ssl_verify=ssl_verify, ssl_key=ssl_key,
+               ssl_cert=ssl_cert, protocol=protocol, url_path=url_path,
+               username=username, password=password, token=token)
